@@ -33,13 +33,15 @@ ivo_excl_missing <- function(df, exclude_missing = FALSE, missing_string = "(Mis
         df[is.na(df[[i]]),i] <- "6049122418972891471204127890512XY"
         df[[i]] <- factor(df[[i]], levels = c(levs, "6049122418972891471204127890512XY"), labels = c(levs, missing_string))
       } else if(sum(is.na(df[[i]]))>0) { df[is.na(df[[i]]), i] <- missing_string }
-    }}
+    }} else {
+      df <- stats::na.omit(df)
+    }
   return(df)
 }
 
 ivo_num_sum <- function(x)
 {
-  suppressWarnings(x <- sum(as.numeric(unlist(x))))
+  suppressWarnings(x <- format(sum(as.numeric(unlist(gsub("\\s+", "", x)))), big.mark = " "))
   x[is.na(x)] <- "-"
   return(x)
 }
